@@ -20,17 +20,11 @@ def pytest_runtest_makereport(item, call):
     outcome = yield
     report = outcome.get_result()
     extra = getattr(report, "extra", [])
-    if report.when == "call":
-        # always add url to report
-        # extra.append(pytest_html.extras.url("http://www.example.com/"))
-        # xfail = hasattr(report, "wasxfail")
-        # if (report.skipped and xfail) or (report.failed and not xfail):
-        #     # only add additional html on failure
-        #     extra.append(pytest_html.extras.html("<div>Additional HTML</div>"))
-        # TODO: raise
-        # pass
-        # if item.module.gif_file
-        extra.append(extras.image(item.module.gif_file, mime_type='image/gif', extension='gif'))
+    if screenshot_option == "all" or "failonly":
+        if report.when == "call":
+            extra.append(extras.image(item.module.gif_file, mime_type='image/gif', extension='gif'))
+            report.extra = extra
+    else:
         report.extra = extra
 
 
@@ -82,6 +76,7 @@ def test_obj(base_url, browser, browser_version, os_version, os_name, remote_fla
         # gif_file = test_obj.write_test_summary()
         # extra.append(extras.image(gif_file, mime_type='image/gif', extension='gif'))
         #
+        test_obj.flush()
         test_obj.log_obj.remove_logger()  # Remove original log handlers
         test_obj.wait(3)
         test_obj.teardown()
